/* AnalysisMasterFile.do */

global MinAge = 18

// 1. Making numbers
** Calories consumed daily in SSB in 2010, 2012, 2014, and 2016 (adults 2010, 2012, 2014, and 2016)
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
sum SSB_kcal if age >= $MinAge & (year == 2010 | year == 2012 | year == 2014 | year == 2016) [aweight = wtdrd1]
local SSB_TotalCal_20142016 = `r(mean)'
clear
set obs 1
gen N = `SSB_TotalCal_20142016'
format N %12.0fc 
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/SSB_TotalCal_2014.tex", replace noquote

** Calories consumed daily in SSB in 2004 (adults 2004)
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
sum SSB_kcal if age >= $MinAge & year == 2004 [aweight = wtdrd1]
local SSB_TotalCal_2004 = `r(mean)'
clear
set obs 1
gen N = `SSB_TotalCal_2004'
format N %12.0fc 
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/SSB_TotalCal_2004.tex", replace noquote

** SSB Percentage of Total Daily Caloric Intake (adults 2010, 2012, 2014, and 2016)
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
gen proportion_calories = SSB_kcal/total_kcal
sum proportion_calories if age >= $MinAge & (year == 2010 | year == 2012 | year == 2014 | year == 2016) [aweight = wtdrd1]
local SSB_PercentCal = `r(mean)'
clear
set obs 1
gen N = `SSB_PercentCal'*100
format N %12.1fc
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/SSB_PercentCal.tex", replace noquote

** Share of Adults Consuming at Least One SSB
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
gen ConsumeAtLeastOneSSB = cond(SSBsConsumed>0,1,0) if SSBsConsumed!=.
sum ConsumeAtLeastOneSSB if age >= $MinAge & (year == 2010 | year == 2012 | year == 2014 | year == 2016) [aweight = wtdrd1]
local ShareConsumeAtLeastOneSSB = `r(mean)'
clear
set obs 1
gen N = `ShareConsumeAtLeastOneSSB'*100
format N %12.0fc 
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/ShareConsumeAtLeastOneSSB.tex", replace noquote


** SSB Consumption in HH <$25,000 (adults 2010, 2012, 2014, and 2016)
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
sum SSB_kcal if age >= $MinAge & (year == 2010 | year == 2012 | year == 2014 | year == 2016) & income_hh <= 5 [aweight = wtdrd1]
local SSB_TotalCal_poor = `r(mean)'
clear
set obs 1
gen N = `SSB_TotalCal_poor'
format N %12.0fc 
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/SSB_TotalCal_poor.tex", replace noquote

** SSB Consumption in HH >=$75,000 (adults 2010, 2012, 2014, and 2016)
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
sum SSB_kcal if age >= $MinAge & (year == 2010 | year == 2012 | year == 2014 | year == 2016) & income_hh == 11 
local SSB_TotalCal_rich = `r(mean)'
clear
set obs 1
gen N = `SSB_TotalCal_rich'
format N %12.0fc 
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/SSB_TotalCal_rich.tex", replace noquote

** Distribution of consumption with PanelViews
capture {
	use "$Externals\..\Externals\Intermediate\PanelViews-FinalData.dta", clear
	sum PVSSBCons [aw=PVSampleWeight1], d
	local Ratio9050 = r(p90)/r(p50)
	local Ratio90Mean = r(p90)/r(mean)

	foreach stat in Ratio9050 Ratio90Mean {
		clear
		set obs 1
		gen N = ``stat''
		format N %12.1fc 
		tostring N, replace force u
		outfile N using "Output/Analysis/NumbersForText/`stat'.tex", replace noquote
	}
}

/*
** SSB Total Sugar Intake (adults 2014)
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
sum SSB_sugar if age >= $MinAge & year == 2014 [aweight = wtdrd1]
local SSB_Sugar = `r(mean)'
clear
set obs 1
gen N = `SSB_Sugar'
format N %12.0fc 
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/SSB_Sugar.tex", replace noquote


** SSB Sugar Percentage of Total Sugar Intake (adults 2014)
use "$Externals/Intermediate/NHANES_Clean", clear, if InSample==1
gen proportion_sugar = SSB_sugar/total_sugar
sum proportion_sugar if age >= $MinAge & year == 2014 [aweight = wtdrd1]
local SSB_PercentSugar = `r(mean)'
clear
set obs 1
gen N = `SSB_PercentSugar'*100
format N %12.0fc 
tostring N, replace force u
outfile N using "Output/Analysis/NumbersForText/SSB_PercentSugar.tex", replace noquote
*/



// 2. Figures
** SSB Consumption by Income
use "$Externals/Intermediate/NHANES_Clean", clear
drop if income_hh == 77 | income_hh == 99 //Removing those with no income data but responded to question
keep if age >= $MinAge //Bleich et al. definition of adult
keep if year == 2010 | year == 2012 | year == 2014 | year == 2016

collapse SSB_kcal [pweight = wtdrd1], by(incomegroup_hh)

twoway (scatter SSB_kcal incomegroup_hh) (lfit SSB_kcal incomegroup_hh), ///
	graphregion(color(white)) xlabel(1(1)8, valuelabel angle(45)) legend(off) ///
	xtitle("Household income") ytitle("SSB consumption (calories/person-day)")
	
graph export "Output/Analysis/SSBConsumptionByIncome.pdf", replace

**World Map of Countries with SSB Taxes
capture {
	shp2dta using "$Externals\Data\Shapefiles\TM_WORLD_BORDERS-0.3.shp", database(worldmap) coordinates(worldcoord) genid(id)
	use worldmap, clear
	drop if NAME == "Antarctica"
		**Tag countries with SSB taxes
		gen tag = 0
		replace tag = 1 if ///
			NAME == "Mexico" | NAME == "Dominica" | NAME == "Barbados"|	NAME == "Peru" | ///
			NAME == "Chile" | NAME == "Bermuda" | NAME == "Norway" | NAME == "Finland" | ///
			NAME == "Estonia" | NAME == "Latvia" | NAME == "United Kingdom" | ///
			NAME == "Ireland" | NAME == "Belgium" | NAME == "France" | NAME == "Hungary" | ///
			NAME == "Portugal" | NAME == "Saint Helena" | NAME == "Saudi Arabia" | ///
			NAME == "Bahrain" | NAME == "United Arab Emirates" | NAME == "India" | ///
			NAME == "Sri Lanka" | NAME == "Thailand" | NAME == "Maldives" | ///
			NAME == "Mauritius" | NAME == "South Africa" | NAME == "Philippines" | ///
			NAME == "Brunei Darussalam" | NAME == "Cook Islands" | NAME == "Fiji" | ///
			NAME == "Palau" | NAME == "French Polynesia" | NAME == "Kiribati" | ///
			NAME == "Nauru" | NAME == "Samoa" | NAME == "Tonga" | NAME == "Vanuatu" | ///
			NAME == "Svalbard"
			
			**Svalbard is part of Norway

	spmap tag using worldcoord, id(id) fc(gs14 green) legenda(off) plotregion(color(white))
	graph export "Code/Lyx/Figures/SSBWorldMap.pdf", replace
	erase "worldmap.dta"
	erase "worldcoord.dta"

}

