// 1. Making food data
// 1.1 Importing and Cleaning
**Dietary Interview--Individual Foods data (Day 1; NHANES)
**Importing raw data for 2004, 2010, 2012, 2014, and 2016. 
**We only use day 1 dietary interview data, following with Bleich et al., 2018)
foreach year in 2004 2010 2012 2014 2016{
if `year' == 2004{
	local letter = "C"
	local var = "dr1mc"
}
else if `year' == 2010{
	local letter = "F"
	local var = ""
}
else if `year' == 2012{
	local letter = "G"
	local var = ""
}
else if `year' == 2014{
	local letter = "H"
	local var = ""
}
else if `year' == 2016{
	local letter = "I"
	local var = ""
}
** Import
import sasxport "$Externals/Data/`year'/DR1IFF_`letter'.XPT", clear

** Rename + Keep		
rename (dr1ifdcd dr1ccmnm dr1ccmtx dr1ikcal dr1isugr) ///
	(foodcode combnum combtype kcal sugar)

keep seqn foodcode combnum combtype kcal sugar wtdrd1 `var'

**Drop duplicates
	* These appear to be data entry errors
duplicates drop seqn combnum if combtype==1, force

** Time label
gen year = `year'
tempfile temp`year'
saveold "`temp`year''"
}

** Modification Codes
**See following post for more details: https://github.com/huntallcott/OptimalSodaTax_JEP/issues/12#issuecomment-479216959
** Import
use "`temp2004'", clear
import sasxport "$Externals/Data/2004/DRXMCD_C.XPT", clear noval
ren drxmc dr1mc

** Time label
gen year = 2004
tempfile mods2004
saveold "`mods2004'"

//1.2 Merging data
** Merge main food data
use "`temp2004'"
append using "`temp2010'"
append using "`temp2012'"
append using "`temp2014'"
append using "`temp2016'"
merge m:1 dr1mc year using "`mods2004'", keep(match master) nogen

**Merge food groups data
**See DataSources.txt for details on how Beverage Food Codes were hand-coded for SSB
preserve
import excel "$Externals/Data/NHANES Beverage Food Codes.xlsx", first clear
keep foodcode SSB
lab var SSB "= 1 if Sugar-Sweetened Beverage"
tempfile labels
saveold "`labels'"
restore

merge m:1 foodcode using "`labels'", keep(match master) nogen
	// 4 unmatched in master data
	// Drop the 4
	// All other food items found a corresponding food group

// 1.3 Creating sugary beverages and sugar added var
**Bleich et al defines SSB as soda, fruit drinks and punches, sports drinks, 
**low-calorie drinks, and other sweetened beverages. Sweetened milk beverages
**are not regarded as SSB.
replace SSB = 0 if SSB!=1

replace kcal = 0 if SSB !=1
replace sugar = 0 if SSB !=1

// 1.4 Collapse data by individual
*Sample weights are identical within seqn and year
collapse (first) wtdrd1 (sum) SSBsConsumed=SSB SSB_kcal=kcal SSB_sugar=sugar, by(seqn year)

tempfile food
saveold "`food'"

// 2. Making demographic data
// 2.1 Importing and Cleaning
**Demographic Variables and Sample Weights
**Importing raw data from 2004 and 2016
foreach year in 2004 2010 2012 2014 2016{
if `year' == 2004{
	local letter = "C"
	local num = "c"
}
else if `year' == 2010{
	local letter = "F"
	local num = 2
}
else if `year' == 2012{
	local letter = "G"
	local num = 2
}
else if `year' == 2014{
	local letter = "H"
	local num = 2
}
else if `year' == 2016{
	local letter = "I"
	local num = 2
}
**Import
import sasxport "$Externals/Data/`year'/DEMO_`letter'.XPT", clear

** Rename + Keep
keep seqn riagendr ridageyr ridreth1 dmdeduc3 dmdeduc2 indhhin`num'
ren indhhin`num' indhhin

** Time label
gen year = `year'
tempfile demo`year'
saveold "`demo`year''"
}

// 2.2 Merge data
use "`demo2004'", clear
append using "`demo2010'"
append using "`demo2012'"
append using "`demo2014'"
append using "`demo2016'"

// 2.3 Clean merged data
**Rename
rename (riagendr ridageyr ridreth1 dmdeduc3 dmdeduc2 indhhin) ///
	(gender age ethnicity education_child education_adult income_hh)
	
** Clean Household Income
** There's a change in how variables are defined in 2015-2016, 2013-2014, and 2003-2004
** Codebook 2015-2016: https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DEMO_I.htm
** Codebook 2013-2014: https://wwwn.cdc.gov/Nchs/Nhanes/2013-2014/DEMO_H.htm
** Codebook 2003-2004: https://wwwn.cdc.gov/Nchs/Nhanes/2003-2004/DEMO_C.htm
replace income_hh = 99 if income_hh == 12 | income_hh == 13
replace income_hh = 11 if income_hh == 14 | income_hh == 15

** IncomeGroup (has income 0-15, 15-25, and then the rest the same as income)
gen incomegroup_hh = income_hh
replace incomegroup_hh = 5 if income_hh==4
replace incomegroup_hh = 4 if inlist(income_hh,1,2,3)
replace incomegroup_hh = incomegroup_hh-3 if income_hh<=20

**Clean Age 
**Similar change as above
replace age = 80 if age>80 & age !=.

** Label	
la def gender ///
	1 Male ///
	2 Female
la val gender gender
	
la def ethnicity ///
	1 "Mexican American" ///
	2 "Other Hispanic" ///
	3 "Non-Hispanic White" ///
	4 "Non-Hispanic Black" ///
	6 "Non-Hispanic Asian" ///
	7 "Other Race - Including Biracial"
la val ethnicity ethnicity
	
la def educchild ///
	0 "Never attended/kindergarten only" ///
	1 "1st grade" ///
	2 "2nd grade" ///
	3 "3rd grade" ///
	4 "4th grade" ///
	5 "5th grade" ///
	6 "6th grade" ///
	7 "7th grade" ///
	8 "8th grade" ///
	9 "9th grade" ///
	10 "10th grade" ///
	11 "11th grade" ///
	12 "12th grade" ///
	13 "High school graduate" ///
	14 "GED or equivalent" ///
	15 "More than high school" ///
	55 "Less than 5th grade" ///
	66 "Less than 9th grade" ///
	77 "Refused" ///
	99 "Don't know" 
la val education_child educchild
	
la def educadult ///
	1 "Less than 9th grade" ///
	2 "9th-11th grade (includes 12th grade w/ no diploma)" ///
	3 "High school graduate/GED or equivalent" ///
	4 "Some college or AA degree" ///
	5 "College graduate or above" ///
	7 "Refused" ///
	9 "Don't know" 
la val education_adult educadult

la def income ///
	1 "$0 to $4,999" ///
	2 "$5,000 to $9,999" ///
	3 "$10,000 to $14,999" ///
	4 "$15,000 to $19,999" ///
	5 "$20,000 to $24,999" ///
	6 "$25,000 to $34,999" ///
	7 "$35,000 to $44,999" ///
	8 "$45,000 to $54,999" ///
	9 "$55,000 to $64,999" ///
	10 "$65,000 to $74,999" ///
	11 "$75,000 and over" ///
	77 "Refused" ///
	99 "Don't Know"
la val income_hh income

la def income_group ///
	1 "$0 to $14,999" ///
	2 "$15,000 to $24,999" ///
	3 "$25,000 to $34,999" ///
	4 "$35,000 to $44,999" ///
	5 "$45,000 to $54,999" ///
	6 "$55,000 to $64,999" ///
	7 "$65,000 to $74,999" ///
	8 "$75,000 and over" ///
	77 "Refused" ///
	99 "Don't Know"
la val incomegroup_hh income_group

**Save
tempfile demographics
saveold "`demographics'"

// 3. Total Nutritional Data
// 3.1 Importing and Cleaning
**Dietary Interview - Total Nutrient Intakes, First Day
**Importing raw data from 2004 and 2016
**Again, following Bleich et al and only using Day 1

foreach year in 2004 2010 2012 2014 2016{
if `year' == 2004{
	local letter = "C"
}
else if `year' == 2010{
	local letter = "F"
}
else if `year' == 2012{
	local letter = "G"
}
else if `year' == 2014{
	local letter = "H"
}		
else if `year' == 2016{
	local letter = "I"
}		
**Importing
import sasxport "$Externals/Data/`year'/DR1TOT_`letter'.XPT", clear

**Rename + Keep
keep seqn dr1tkcal dr1tsugr 
ren (dr1tkcal dr1tsugr) (total_kcal total_sugar)

** time label
gen year = `year'
tempfile temp`year'
saveold "`temp`year''"
}

// 3.2 Merge 2012 and 2016 data
use "`temp2004'"
append using "`temp2010'"
append using "`temp2012'"
append using "`temp2014'"
append using "`temp2016'"

// 3.3 Save
tempfile total
saveold "`total'"

// 4. Cleaned Data
// 4.1 Merging Data
use "`food'", clear
merge 1:1 seqn using "`total'"
	drop if _m == 2
	drop _m
merge 1:1 seqn using "`demographics'"
	drop if _m == 2
	drop _m

	// 4.2 Labeling
la var seqn "Interviewee ID"
la var wtdrd1 "Sample weight"
la var SSBsConsumed "Number of SSBs consumed in a day"
la var SSB_kcal "Daily Calories from SSB Consumption"
la var SSB_sugar "Amount of sugar consumed from SSBs"
la var total_kcal "Daily Total Calories"
la var total_sugar "Daily Total Sugar Consumption"
la var gender "1= Male, 2-Female"
la var age "=80 if age >=80"
la var ethnicity "Ethnicity"
la var education_child "Education of children"
la var education_adult "Education of adults"
la var income_hh "Household Income" 

// 4.3 Dropping observations with missing values in either individual food or total intake data
gen InSample = 1
foreach var in SSBsConsumed SSB_kcal SSB_sugar total_kcal total_sugar {
	replace InSample = 0 if `var' == .
}

// 4.4 Save
saveold "$Externals/Intermediate/NHANES_Clean.dta", replace
